@@ -1,6 +1,6 @@
 import xcffib
 import struct
-import six
+import io
 MAJOR_VERSION = 0
 MINOR_VERSION = 0
 key = xcffib.ExtensionKey("BIG-REQUESTS")
@@ -18,7 +18,7 @@ class EnableCookie(xcffib.Cookie):
     reply_type = EnableReply
 class bigreqExtension(xcffib.Extension):
     def Enable(self, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         return self.send_request(0, buf, EnableCookie, is_checked=is_checked)
 xcffib._add_ext(key, bigreqExtension, _events, _errors)
