@@ -1,6 +1,6 @@
 import xcffib
 import struct
-import six
+import io
 MAJOR_VERSION = 1
 MINOR_VERSION = 0
 key = xcffib.ExtensionKey("Generic Event Extension")
@@ -18,7 +18,7 @@ class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 class geExtension(xcffib.Extension):
     def QueryVersion(self, client_major_version, client_minor_version, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xHH", client_major_version, client_minor_version))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
 xcffib._add_ext(key, geExtension, _events, _errors)
