@@ -1,6 +1,6 @@
 import xcffib
 import struct
-import six
+import io
 MAJOR_VERSION = 0
 MINOR_VERSION = 11
 key = xcffib.ExtensionKey("RENDER")
@@ -107,7 +107,7 @@ class PictFormatError(xcffib.Error):
         unpacker.unpack("xx2x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 0))
         buf.write(struct.pack("=x2x"))
         return buf.getvalue()
@@ -122,7 +122,7 @@ class PictureError(xcffib.Error):
         unpacker.unpack("xx2x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 1))
         buf.write(struct.pack("=x2x"))
         return buf.getvalue()
@@ -137,7 +137,7 @@ class PictOpError(xcffib.Error):
         unpacker.unpack("xx2x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 2))
         buf.write(struct.pack("=x2x"))
         return buf.getvalue()
@@ -152,7 +152,7 @@ class GlyphSetError(xcffib.Error):
         unpacker.unpack("xx2x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 3))
         buf.write(struct.pack("=x2x"))
         return buf.getvalue()
@@ -167,7 +167,7 @@ class GlyphError(xcffib.Error):
         unpacker.unpack("xx2x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 4))
         buf.write(struct.pack("=x2x"))
         return buf.getvalue()
@@ -182,7 +182,7 @@ class DIRECTFORMAT(xcffib.Struct):
         self.red_shift, self.red_mask, self.green_shift, self.green_mask, self.blue_shift, self.blue_mask, self.alpha_shift, self.alpha_mask = unpacker.unpack("HHHHHHHH")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=HHHHHHHH", self.red_shift, self.red_mask, self.green_shift, self.green_mask, self.blue_shift, self.blue_mask, self.alpha_shift, self.alpha_mask))
         return buf.getvalue()
     fixed_size = 16
@@ -209,9 +209,10 @@ class PICTFORMINFO(xcffib.Struct):
         self.colormap, = unpacker.unpack("I")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
-        buf.write(struct.pack("=IBB2xI", self.id, self.type, self.depth, self.colormap))
+        buf = io.BytesIO()
+        buf.write(struct.pack("=IBB2x", self.id, self.type, self.depth))
         buf.write(self.direct.pack() if hasattr(self.direct, "pack") else DIRECTFORMAT.synthetic(*self.direct).pack())
+        buf.write(struct.pack("=I", self.colormap))
         return buf.getvalue()
     @classmethod
     def synthetic(cls, id, type, depth, direct, colormap):
@@ -231,7 +232,7 @@ class PICTVISUAL(xcffib.Struct):
         self.visual, self.format = unpacker.unpack("II")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=II", self.visual, self.format))
         return buf.getvalue()
     fixed_size = 8
@@ -251,7 +252,7 @@ class PICTDEPTH(xcffib.Struct):
         self.visuals = xcffib.List(unpacker, PICTVISUAL, self.num_visuals)
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=BxH4x", self.depth, self.num_visuals))
         buf.write(xcffib.pack_list(self.visuals, PICTVISUAL))
         return buf.getvalue()
@@ -272,7 +273,7 @@ class PICTSCREEN(xcffib.Struct):
         self.depths = xcffib.List(unpacker, PICTDEPTH, self.num_depths)
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=II", self.num_depths, self.fallback))
         buf.write(xcffib.pack_list(self.depths, PICTDEPTH))
         return buf.getvalue()
@@ -292,7 +293,7 @@ class INDEXVALUE(xcffib.Struct):
         self.pixel, self.red, self.green, self.blue, self.alpha = unpacker.unpack("IHHHH")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=IHHHH", self.pixel, self.red, self.green, self.blue, self.alpha))
         return buf.getvalue()
     fixed_size = 12
@@ -314,7 +315,7 @@ class COLOR(xcffib.Struct):
         self.red, self.green, self.blue, self.alpha = unpacker.unpack("HHHH")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=HHHH", self.red, self.green, self.blue, self.alpha))
         return buf.getvalue()
     fixed_size = 8
@@ -335,7 +336,7 @@ class POINTFIX(xcffib.Struct):
         self.x, self.y = unpacker.unpack("ii")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=ii", self.x, self.y))
         return buf.getvalue()
     fixed_size = 8
@@ -356,7 +357,7 @@ class LINEFIX(xcffib.Struct):
         self.p2 = POINTFIX(unpacker)
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(self.p1.pack() if hasattr(self.p1, "pack") else POINTFIX.synthetic(*self.p1).pack())
         buf.write(self.p2.pack() if hasattr(self.p2, "pack") else POINTFIX.synthetic(*self.p2).pack())
         return buf.getvalue()
@@ -379,7 +380,7 @@ class TRIANGLE(xcffib.Struct):
         self.p3 = POINTFIX(unpacker)
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(self.p1.pack() if hasattr(self.p1, "pack") else POINTFIX.synthetic(*self.p1).pack())
         buf.write(self.p2.pack() if hasattr(self.p2, "pack") else POINTFIX.synthetic(*self.p2).pack())
         buf.write(self.p3.pack() if hasattr(self.p3, "pack") else POINTFIX.synthetic(*self.p3).pack())
@@ -403,7 +404,7 @@ class TRAPEZOID(xcffib.Struct):
         self.right = LINEFIX(unpacker)
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=ii", self.top, self.bottom))
         buf.write(self.left.pack() if hasattr(self.left, "pack") else LINEFIX.synthetic(*self.left).pack())
         buf.write(self.right.pack() if hasattr(self.right, "pack") else LINEFIX.synthetic(*self.right).pack())
@@ -425,7 +426,7 @@ class GLYPHINFO(xcffib.Struct):
         self.width, self.height, self.x, self.y, self.x_off, self.y_off = unpacker.unpack("HHhhhh")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=HHhhhh", self.width, self.height, self.x, self.y, self.x_off, self.y_off))
         return buf.getvalue()
     fixed_size = 12
@@ -484,7 +485,7 @@ class TRANSFORM(xcffib.Struct):
         self.matrix11, self.matrix12, self.matrix13, self.matrix21, self.matrix22, self.matrix23, self.matrix31, self.matrix32, self.matrix33 = unpacker.unpack("iiiiiiiii")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=iiiiiiiii", self.matrix11, self.matrix12, self.matrix13, self.matrix21, self.matrix22, self.matrix23, self.matrix31, self.matrix32, self.matrix33))
         return buf.getvalue()
     fixed_size = 36
@@ -523,7 +524,7 @@ class ANIMCURSORELT(xcffib.Struct):
         self.cursor, self.delay = unpacker.unpack("II")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=II", self.cursor, self.delay))
         return buf.getvalue()
     fixed_size = 8
@@ -542,7 +543,7 @@ class SPANFIX(xcffib.Struct):
         self.l, self.r, self.y = unpacker.unpack("iii")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=iii", self.l, self.r, self.y))
         return buf.getvalue()
     fixed_size = 12
@@ -564,7 +565,7 @@ class TRAP(xcffib.Struct):
         self.bot = SPANFIX(unpacker)
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(self.top.pack() if hasattr(self.top, "pack") else SPANFIX.synthetic(*self.top).pack())
         buf.write(self.bot.pack() if hasattr(self.bot, "pack") else SPANFIX.synthetic(*self.bot).pack())
         return buf.getvalue()
@@ -576,161 +577,241 @@ class TRAP(xcffib.Struct):
         return self
 class renderExtension(xcffib.Extension):
     def QueryVersion(self, client_major_version, client_minor_version, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", client_major_version, client_minor_version))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
     def QueryPictFormats(self, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         return self.send_request(1, buf, QueryPictFormatsCookie, is_checked=is_checked)
     def QueryPictIndexValues(self, format, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", format))
         return self.send_request(2, buf, QueryPictIndexValuesCookie, is_checked=is_checked)
     def CreatePicture(self, pid, drawable, format, value_mask, value_list, is_checked=False):
-        buf = six.BytesIO()
-        buf.write(struct.pack("=xx2xIII", pid, drawable, format))
-        buf.write(struct.pack("=I", value_mask))
-        buf.write(xcffib.pack_list(value_list, "I"))
+        buf = io.BytesIO()
+        buf.write(struct.pack("=xx2xIIII", pid, drawable, format, value_mask))
+        if value_mask & CP.Repeat:
+            repeat = value_list.pop(0)
+            buf.write(struct.pack("=I", repeat))
+        if value_mask & CP.AlphaMap:
+            alphamap = value_list.pop(0)
+            buf.write(struct.pack("=I", alphamap))
+        if value_mask & CP.AlphaXOrigin:
+            alphaxorigin = value_list.pop(0)
+            buf.write(struct.pack("=i", alphaxorigin))
+        if value_mask & CP.AlphaYOrigin:
+            alphayorigin = value_list.pop(0)
+            buf.write(struct.pack("=i", alphayorigin))
+        if value_mask & CP.ClipXOrigin:
+            clipxorigin = value_list.pop(0)
+            buf.write(struct.pack("=i", clipxorigin))
+        if value_mask & CP.ClipYOrigin:
+            clipyorigin = value_list.pop(0)
+            buf.write(struct.pack("=i", clipyorigin))
+        if value_mask & CP.ClipMask:
+            clipmask = value_list.pop(0)
+            buf.write(struct.pack("=I", clipmask))
+        if value_mask & CP.GraphicsExposure:
+            graphicsexposure = value_list.pop(0)
+            buf.write(struct.pack("=I", graphicsexposure))
+        if value_mask & CP.SubwindowMode:
+            subwindowmode = value_list.pop(0)
+            buf.write(struct.pack("=I", subwindowmode))
+        if value_mask & CP.PolyEdge:
+            polyedge = value_list.pop(0)
+            buf.write(struct.pack("=I", polyedge))
+        if value_mask & CP.PolyMode:
+            polymode = value_list.pop(0)
+            buf.write(struct.pack("=I", polymode))
+        if value_mask & CP.Dither:
+            dither = value_list.pop(0)
+            buf.write(struct.pack("=I", dither))
+        if value_mask & CP.ComponentAlpha:
+            componentalpha = value_list.pop(0)
+            buf.write(struct.pack("=I", componentalpha))
         return self.send_request(4, buf, is_checked=is_checked)
     def ChangePicture(self, picture, value_mask, value_list, is_checked=False):
-        buf = six.BytesIO()
-        buf.write(struct.pack("=xx2xI", picture))
-        buf.write(struct.pack("=I", value_mask))
-        buf.write(xcffib.pack_list(value_list, "I"))
+        buf = io.BytesIO()
+        buf.write(struct.pack("=xx2xII", picture, value_mask))
+        if value_mask & CP.Repeat:
+            repeat = value_list.pop(0)
+            buf.write(struct.pack("=I", repeat))
+        if value_mask & CP.AlphaMap:
+            alphamap = value_list.pop(0)
+            buf.write(struct.pack("=I", alphamap))
+        if value_mask & CP.AlphaXOrigin:
+            alphaxorigin = value_list.pop(0)
+            buf.write(struct.pack("=i", alphaxorigin))
+        if value_mask & CP.AlphaYOrigin:
+            alphayorigin = value_list.pop(0)
+            buf.write(struct.pack("=i", alphayorigin))
+        if value_mask & CP.ClipXOrigin:
+            clipxorigin = value_list.pop(0)
+            buf.write(struct.pack("=i", clipxorigin))
+        if value_mask & CP.ClipYOrigin:
+            clipyorigin = value_list.pop(0)
+            buf.write(struct.pack("=i", clipyorigin))
+        if value_mask & CP.ClipMask:
+            clipmask = value_list.pop(0)
+            buf.write(struct.pack("=I", clipmask))
+        if value_mask & CP.GraphicsExposure:
+            graphicsexposure = value_list.pop(0)
+            buf.write(struct.pack("=I", graphicsexposure))
+        if value_mask & CP.SubwindowMode:
+            subwindowmode = value_list.pop(0)
+            buf.write(struct.pack("=I", subwindowmode))
+        if value_mask & CP.PolyEdge:
+            polyedge = value_list.pop(0)
+            buf.write(struct.pack("=I", polyedge))
+        if value_mask & CP.PolyMode:
+            polymode = value_list.pop(0)
+            buf.write(struct.pack("=I", polymode))
+        if value_mask & CP.Dither:
+            dither = value_list.pop(0)
+            buf.write(struct.pack("=I", dither))
+        if value_mask & CP.ComponentAlpha:
+            componentalpha = value_list.pop(0)
+            buf.write(struct.pack("=I", componentalpha))
         return self.send_request(5, buf, is_checked=is_checked)
     def SetPictureClipRectangles(self, picture, clip_x_origin, clip_y_origin, rectangles_len, rectangles, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIhh", picture, clip_x_origin, clip_y_origin))
         buf.write(xcffib.pack_list(rectangles, xproto.RECTANGLE))
         return self.send_request(6, buf, is_checked=is_checked)
     def FreePicture(self, picture, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", picture))
         return self.send_request(7, buf, is_checked=is_checked)
     def Composite(self, op, src, mask, dst, src_x, src_y, mask_x, mask_y, dst_x, dst_y, width, height, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xB3xIIIhhhhhhHH", op, src, mask, dst, src_x, src_y, mask_x, mask_y, dst_x, dst_y, width, height))
         return self.send_request(8, buf, is_checked=is_checked)
     def Trapezoids(self, op, src, dst, mask_format, src_x, src_y, traps_len, traps, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xB3xIIIhh", op, src, dst, mask_format, src_x, src_y))
         buf.write(xcffib.pack_list(traps, TRAPEZOID))
         return self.send_request(10, buf, is_checked=is_checked)
     def Triangles(self, op, src, dst, mask_format, src_x, src_y, triangles_len, triangles, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xB3xIIIhh", op, src, dst, mask_format, src_x, src_y))
         buf.write(xcffib.pack_list(triangles, TRIANGLE))
         return self.send_request(11, buf, is_checked=is_checked)
     def TriStrip(self, op, src, dst, mask_format, src_x, src_y, points_len, points, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xB3xIIIhh", op, src, dst, mask_format, src_x, src_y))
         buf.write(xcffib.pack_list(points, POINTFIX))
         return self.send_request(12, buf, is_checked=is_checked)
     def TriFan(self, op, src, dst, mask_format, src_x, src_y, points_len, points, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xB3xIIIhh", op, src, dst, mask_format, src_x, src_y))
         buf.write(xcffib.pack_list(points, POINTFIX))
         return self.send_request(13, buf, is_checked=is_checked)
     def CreateGlyphSet(self, gsid, format, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", gsid, format))
         return self.send_request(17, buf, is_checked=is_checked)
     def ReferenceGlyphSet(self, gsid, existing, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", gsid, existing))
         return self.send_request(18, buf, is_checked=is_checked)
     def FreeGlyphSet(self, glyphset, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", glyphset))
         return self.send_request(19, buf, is_checked=is_checked)
     def AddGlyphs(self, glyphset, glyphs_len, glyphids, glyphs, data_len, data, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xII", glyphset, glyphs_len))
         buf.write(xcffib.pack_list(glyphids, "I"))
         buf.write(xcffib.pack_list(glyphs, GLYPHINFO))
         buf.write(xcffib.pack_list(data, "B"))
         return self.send_request(20, buf, is_checked=is_checked)
     def FreeGlyphs(self, glyphset, glyphs_len, glyphs, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", glyphset))
         buf.write(xcffib.pack_list(glyphs, "I"))
         return self.send_request(22, buf, is_checked=is_checked)
     def CompositeGlyphs8(self, op, src, dst, mask_format, glyphset, src_x, src_y, glyphcmds_len, glyphcmds, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xB3xIIIIhh", op, src, dst, mask_format, glyphset, src_x, src_y))
         buf.write(xcffib.pack_list(glyphcmds, "B"))
         return self.send_request(23, buf, is_checked=is_checked)
     def CompositeGlyphs16(self, op, src, dst, mask_format, glyphset, src_x, src_y, glyphcmds_len, glyphcmds, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xB3xIIIIhh", op, src, dst, mask_format, glyphset, src_x, src_y))
         buf.write(xcffib.pack_list(glyphcmds, "B"))
         return self.send_request(24, buf, is_checked=is_checked)
     def CompositeGlyphs32(self, op, src, dst, mask_format, glyphset, src_x, src_y, glyphcmds_len, glyphcmds, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xB3xIIIIhh", op, src, dst, mask_format, glyphset, src_x, src_y))
         buf.write(xcffib.pack_list(glyphcmds, "B"))
         return self.send_request(25, buf, is_checked=is_checked)
     def FillRectangles(self, op, dst, color, rects_len, rects, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xB3xI", op, dst))
         buf.write(color.pack() if hasattr(color, "pack") else COLOR.synthetic(*color).pack())
         buf.write(xcffib.pack_list(rects, xproto.RECTANGLE))
         return self.send_request(26, buf, is_checked=is_checked)
     def CreateCursor(self, cid, source, x, y, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIHH", cid, source, x, y))
         return self.send_request(27, buf, is_checked=is_checked)
     def SetPictureTransform(self, picture, transform, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", picture))
         buf.write(transform.pack() if hasattr(transform, "pack") else TRANSFORM.synthetic(*transform).pack())
         return self.send_request(28, buf, is_checked=is_checked)
     def QueryFilters(self, drawable, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", drawable))
         return self.send_request(29, buf, QueryFiltersCookie, is_checked=is_checked)
     def SetPictureFilter(self, picture, filter_len, filter, values_len, values, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIH2x", picture, filter_len))
         buf.write(xcffib.pack_list(filter, "c"))
         buf.write(xcffib.pack_list(values, "i"))
         return self.send_request(30, buf, is_checked=is_checked)
     def CreateAnimCursor(self, cid, cursors_len, cursors, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", cid))
         buf.write(xcffib.pack_list(cursors, ANIMCURSORELT))
         return self.send_request(31, buf, is_checked=is_checked)
     def AddTraps(self, picture, x_off, y_off, traps_len, traps, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIhh", picture, x_off, y_off))
         buf.write(xcffib.pack_list(traps, TRAP))
         return self.send_request(32, buf, is_checked=is_checked)
     def CreateSolidFill(self, picture, color, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xI", picture))
         buf.write(color.pack() if hasattr(color, "pack") else COLOR.synthetic(*color).pack())
         return self.send_request(33, buf, is_checked=is_checked)
-    def CreateLinearGradient(self, picture, num_stops, p1, p2, stops, colors, is_checked=False):
-        buf = six.BytesIO()
-        buf.write(struct.pack("=xx2xII", picture, num_stops))
+    def CreateLinearGradient(self, picture, p1, p2, num_stops, stops, colors, is_checked=False):
+        buf = io.BytesIO()
+        buf.write(struct.pack("=xx2xI", picture))
         buf.write(p1.pack() if hasattr(p1, "pack") else POINTFIX.synthetic(*p1).pack())
         buf.write(p2.pack() if hasattr(p2, "pack") else POINTFIX.synthetic(*p2).pack())
+        buf.write(struct.pack("=I", num_stops))
         buf.write(xcffib.pack_list(stops, "i"))
         buf.write(xcffib.pack_list(colors, COLOR))
         return self.send_request(34, buf, is_checked=is_checked)
-    def CreateRadialGradient(self, picture, inner_radius, outer_radius, num_stops, inner, outer, stops, colors, is_checked=False):
-        buf = six.BytesIO()
-        buf.write(struct.pack("=xx2xIiiI", picture, inner_radius, outer_radius, num_stops))
+    def CreateRadialGradient(self, picture, inner, outer, inner_radius, outer_radius, num_stops, stops, colors, is_checked=False):
+        buf = io.BytesIO()
+        buf.write(struct.pack("=xx2xI", picture))
         buf.write(inner.pack() if hasattr(inner, "pack") else POINTFIX.synthetic(*inner).pack())
         buf.write(outer.pack() if hasattr(outer, "pack") else POINTFIX.synthetic(*outer).pack())
+        buf.write(struct.pack("=i", inner_radius))
+        buf.write(struct.pack("=i", outer_radius))
+        buf.write(struct.pack("=I", num_stops))
         buf.write(xcffib.pack_list(stops, "i"))
         buf.write(xcffib.pack_list(colors, COLOR))
         return self.send_request(35, buf, is_checked=is_checked)
-    def CreateConicalGradient(self, picture, angle, num_stops, center, stops, colors, is_checked=False):
-        buf = six.BytesIO()
-        buf.write(struct.pack("=xx2xIiI", picture, angle, num_stops))
+    def CreateConicalGradient(self, picture, center, angle, num_stops, stops, colors, is_checked=False):
+        buf = io.BytesIO()
+        buf.write(struct.pack("=xx2xI", picture))
         buf.write(center.pack() if hasattr(center, "pack") else POINTFIX.synthetic(*center).pack())
+        buf.write(struct.pack("=i", angle))
+        buf.write(struct.pack("=I", num_stops))
         buf.write(xcffib.pack_list(stops, "i"))
         buf.write(xcffib.pack_list(colors, COLOR))
         return self.send_request(36, buf, is_checked=is_checked)
