@@ -59,8 +59,9 @@ class SYSTEMCOUNTER(xcffib.Struct):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = io.BytesIO()
-        buf.write(struct.pack("=IH", self.counter, self.name_len))
+        buf.write(struct.pack("=I", self.counter))
         buf.write(self.resolution.pack() if hasattr(self.resolution, "pack") else INT64.synthetic(*self.resolution).pack())
+        buf.write(struct.pack("=H", self.name_len))
         buf.write(xcffib.pack_list(self.name, "c"))
         return buf.getvalue()
     @classmethod
@@ -83,8 +84,9 @@ class TRIGGER(xcffib.Struct):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = io.BytesIO()
-        buf.write(struct.pack("=III", self.counter, self.wait_type, self.test_type))
+        buf.write(struct.pack("=II", self.counter, self.wait_type))
         buf.write(self.wait_value.pack() if hasattr(self.wait_value, "pack") else INT64.synthetic(*self.wait_value).pack())
+        buf.write(struct.pack("=I", self.test_type))
         return buf.getvalue()
     @classmethod
     def synthetic(cls, counter, wait_type, wait_value, test_type):
@@ -226,9 +228,13 @@ class CounterNotifyEvent(xcffib.Event):
     def pack(self):
         buf = io.BytesIO()
         buf.write(struct.pack("=B", 0))
-        buf.write(struct.pack("=B2xIIHBx", self.kind, self.counter, self.timestamp, self.count, self.destroyed))
+        buf.write(struct.pack("=B2xI", self.kind, self.counter))
         buf.write(self.wait_value.pack() if hasattr(self.wait_value, "pack") else INT64.synthetic(*self.wait_value).pack())
         buf.write(self.counter_value.pack() if hasattr(self.counter_value, "pack") else INT64.synthetic(*self.counter_value).pack())
+        buf.write(struct.pack("=I", self.timestamp))
+        buf.write(struct.pack("=H", self.count))
+        buf.write(struct.pack("=B", self.destroyed))
+        buf.write(struct.pack("=x", ))
         buf_len = len(buf.getvalue())
         if buf_len < 32:
             buf.write(struct.pack("x" * (32 - buf_len)))
@@ -260,9 +266,12 @@ class AlarmNotifyEvent(xcffib.Event):
     def pack(self):
         buf = io.BytesIO()
         buf.write(struct.pack("=B", 1))
-        buf.write(struct.pack("=B2xIIB3x", self.kind, self.alarm, self.timestamp, self.state))
+        buf.write(struct.pack("=B2xI", self.kind, self.alarm))
         buf.write(self.counter_value.pack() if hasattr(self.counter_value, "pack") else INT64.synthetic(*self.counter_value).pack())
         buf.write(self.alarm_value.pack() if hasattr(self.alarm_value, "pack") else INT64.synthetic(*self.alarm_value).pack())
+        buf.write(struct.pack("=I", self.timestamp))
+        buf.write(struct.pack("=B", self.state))
+        buf.write(struct.pack("=3x", ))
         buf_len = len(buf.getvalue())
         if buf_len < 32:
             buf.write(struct.pack("x" * (32 - buf_len)))
