@@ -1,6 +1,6 @@
 import xcffib
 import struct
-import six
+import io
 MAJOR_VERSION = 2
 MINOR_VERSION = 2
 key = xcffib.ExtensionKey("XFree86-VidModeExtension")
@@ -34,7 +34,7 @@ class ModeInfo(xcffib.Struct):
         self.dotclock, self.hdisplay, self.hsyncstart, self.hsyncend, self.htotal, self.hskew, self.vdisplay, self.vsyncstart, self.vsyncend, self.vtotal, self.flags, self.privsize = unpacker.unpack("IHHHHIHHHH4xI12xI")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=IHHHHIHHHH4xI12xI", self.dotclock, self.hdisplay, self.hsyncstart, self.hsyncend, self.htotal, self.hskew, self.vdisplay, self.vsyncstart, self.vsyncend, self.vtotal, self.flags, self.privsize))
         return buf.getvalue()
     fixed_size = 48
@@ -190,7 +190,7 @@ class BadClockError(xcffib.Error):
         unpacker.unpack("xx2x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 0))
         buf.write(struct.pack("=x2x"))
         return buf.getvalue()
@@ -205,7 +205,7 @@ class BadHTimingsError(xcffib.Error):
         unpacker.unpack("xx2x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 1))
         buf.write(struct.pack("=x2x"))
         return buf.getvalue()
@@ -220,7 +220,7 @@ class BadVTimingsError(xcffib.Error):
         unpacker.unpack("xx2x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 2))
         buf.write(struct.pack("=x2x"))
         return buf.getvalue()
@@ -235,7 +235,7 @@ class ModeUnsuitableError(xcffib.Error):
         unpacker.unpack("xx2x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 3))
         buf.write(struct.pack("=x2x"))
         return buf.getvalue()
@@ -250,7 +250,7 @@ class ExtensionDisabledError(xcffib.Error):
         unpacker.unpack("xx2x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 4))
         buf.write(struct.pack("=x2x"))
         return buf.getvalue()
@@ -265,7 +265,7 @@ class ClientNotLocalError(xcffib.Error):
         unpacker.unpack("xx2x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 5))
         buf.write(struct.pack("=x2x"))
         return buf.getvalue()
@@ -280,7 +280,7 @@ class ZoomLockedError(xcffib.Error):
         unpacker.unpack("xx2x")
         self.bufsize = unpacker.offset - base
     def pack(self):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=B", 6))
         buf.write(struct.pack("=x2x"))
         return buf.getvalue()
@@ -288,95 +288,95 @@ BadZoomLocked = ZoomLockedError
 _errors[6] = ZoomLockedError
 class xf86vidmodeExtension(xcffib.Extension):
     def QueryVersion(self, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2x"))
         return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
     def GetModeLine(self, screen, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2x", screen))
         return self.send_request(1, buf, GetModeLineCookie, is_checked=is_checked)
     def ModModeLine(self, screen, hdisplay, hsyncstart, hsyncend, htotal, hskew, vdisplay, vsyncstart, vsyncend, vtotal, flags, privsize, private, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIHHHHHHHHH2xI12xI", screen, hdisplay, hsyncstart, hsyncend, htotal, hskew, vdisplay, vsyncstart, vsyncend, vtotal, flags, privsize))
         buf.write(xcffib.pack_list(private, "B"))
         return self.send_request(2, buf, is_checked=is_checked)
     def SwitchMode(self, screen, zoom, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xHH", screen, zoom))
         return self.send_request(3, buf, is_checked=is_checked)
     def GetMonitor(self, screen, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2x", screen))
         return self.send_request(4, buf, GetMonitorCookie, is_checked=is_checked)
     def LockModeSwitch(self, screen, lock, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xHH", screen, lock))
         return self.send_request(5, buf, is_checked=is_checked)
     def GetAllModeLines(self, screen, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2x", screen))
         return self.send_request(6, buf, GetAllModeLinesCookie, is_checked=is_checked)
     def AddModeLine(self, screen, dotclock, hdisplay, hsyncstart, hsyncend, htotal, hskew, vdisplay, vsyncstart, vsyncend, vtotal, flags, privsize, after_dotclock, after_hdisplay, after_hsyncstart, after_hsyncend, after_htotal, after_hskew, after_vdisplay, after_vsyncstart, after_vsyncend, after_vtotal, after_flags, private, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIHHHHHHHHH2xI12xIIHHHHHHHHH2xI12x", screen, dotclock, hdisplay, hsyncstart, hsyncend, htotal, hskew, vdisplay, vsyncstart, vsyncend, vtotal, flags, privsize, after_dotclock, after_hdisplay, after_hsyncstart, after_hsyncend, after_htotal, after_hskew, after_vdisplay, after_vsyncstart, after_vsyncend, after_vtotal, after_flags))
         buf.write(xcffib.pack_list(private, "B"))
         return self.send_request(7, buf, is_checked=is_checked)
     def DeleteModeLine(self, screen, dotclock, hdisplay, hsyncstart, hsyncend, htotal, hskew, vdisplay, vsyncstart, vsyncend, vtotal, flags, privsize, private, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIHHHHHHHHH2xI12xI", screen, dotclock, hdisplay, hsyncstart, hsyncend, htotal, hskew, vdisplay, vsyncstart, vsyncend, vtotal, flags, privsize))
         buf.write(xcffib.pack_list(private, "B"))
         return self.send_request(8, buf, is_checked=is_checked)
     def ValidateModeLine(self, screen, dotclock, hdisplay, hsyncstart, hsyncend, htotal, hskew, vdisplay, vsyncstart, vsyncend, vtotal, flags, privsize, private, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIHHHHHHHHH2xI12xI", screen, dotclock, hdisplay, hsyncstart, hsyncend, htotal, hskew, vdisplay, vsyncstart, vsyncend, vtotal, flags, privsize))
         buf.write(xcffib.pack_list(private, "B"))
         return self.send_request(9, buf, ValidateModeLineCookie, is_checked=is_checked)
     def SwitchToMode(self, screen, dotclock, hdisplay, hsyncstart, hsyncend, htotal, hskew, vdisplay, vsyncstart, vsyncend, vtotal, flags, privsize, private, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xIIHHHHHHHHH2xI12xI", screen, dotclock, hdisplay, hsyncstart, hsyncend, htotal, hskew, vdisplay, vsyncstart, vsyncend, vtotal, flags, privsize))
         buf.write(xcffib.pack_list(private, "B"))
         return self.send_request(10, buf, is_checked=is_checked)
     def GetViewPort(self, screen, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2x", screen))
         return self.send_request(11, buf, GetViewPortCookie, is_checked=is_checked)
     def SetViewPort(self, screen, x, y, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2xII", screen, x, y))
         return self.send_request(12, buf, is_checked=is_checked)
     def GetDotClocks(self, screen, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2x", screen))
         return self.send_request(13, buf, GetDotClocksCookie, is_checked=is_checked)
     def SetClientVersion(self, major, minor, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xHH", major, minor))
         return self.send_request(14, buf, is_checked=is_checked)
     def SetGamma(self, screen, red, green, blue, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2xIII12x", screen, red, green, blue))
         return self.send_request(15, buf, is_checked=is_checked)
     def GetGamma(self, screen, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH26x", screen))
         return self.send_request(16, buf, GetGammaCookie, is_checked=is_checked)
     def GetGammaRamp(self, screen, size, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xHH", screen, size))
         return self.send_request(17, buf, GetGammaRampCookie, is_checked=is_checked)
     def SetGammaRamp(self, screen, size, red, green, blue, is_checked=False):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xHH", screen, size))
         buf.write(xcffib.pack_list(red, "H"))
         buf.write(xcffib.pack_list(green, "H"))
         buf.write(xcffib.pack_list(blue, "H"))
         return self.send_request(18, buf, is_checked=is_checked)
     def GetGammaRampSize(self, screen, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2x", screen))
         return self.send_request(19, buf, GetGammaRampSizeCookie, is_checked=is_checked)
     def GetPermissions(self, screen, is_checked=True):
-        buf = six.BytesIO()
+        buf = io.BytesIO()
         buf.write(struct.pack("=xx2xH2x", screen))
         return self.send_request(20, buf, GetPermissionsCookie, is_checked=is_checked)
 xcffib._add_ext(key, xf86vidmodeExtension, _events, _errors)
