@@ -202,9 +202,30 @@ class ImageFormatInfo(xcffib.Struct):
         self.bufsize = unpacker.offset - base
     def pack(self):
         buf = io.BytesIO()
-        buf.write(struct.pack("=IBB2xBB2xB3xIIIB3xIIIIIIIIIB11x", self.id, self.type, self.byte_order, self.bpp, self.num_planes, self.depth, self.red_mask, self.green_mask, self.blue_mask, self.format, self.y_sample_bits, self.u_sample_bits, self.v_sample_bits, self.vhorz_y_period, self.vhorz_u_period, self.vhorz_v_period, self.vvert_y_period, self.vvert_u_period, self.vvert_v_period, self.vscanline_order))
+        buf.write(struct.pack("=IBB2x", self.id, self.type, self.byte_order))
         buf.write(xcffib.pack_list(self.guid, "B"))
+        buf.write(struct.pack("=B", self.bpp))
+        buf.write(struct.pack("=B", self.num_planes))
+        buf.write(struct.pack("=2x", ))
+        buf.write(struct.pack("=B", self.depth))
+        buf.write(struct.pack("=3x", ))
+        buf.write(struct.pack("=I", self.red_mask))
+        buf.write(struct.pack("=I", self.green_mask))
+        buf.write(struct.pack("=I", self.blue_mask))
+        buf.write(struct.pack("=B", self.format))
+        buf.write(struct.pack("=3x", ))
+        buf.write(struct.pack("=I", self.y_sample_bits))
+        buf.write(struct.pack("=I", self.u_sample_bits))
+        buf.write(struct.pack("=I", self.v_sample_bits))
+        buf.write(struct.pack("=I", self.vhorz_y_period))
+        buf.write(struct.pack("=I", self.vhorz_u_period))
+        buf.write(struct.pack("=I", self.vhorz_v_period))
+        buf.write(struct.pack("=I", self.vvert_y_period))
+        buf.write(struct.pack("=I", self.vvert_u_period))
+        buf.write(struct.pack("=I", self.vvert_v_period))
         buf.write(xcffib.pack_list(self.vcomp_order, "B"))
+        buf.write(struct.pack("=B", self.vscanline_order))
+        buf.write(struct.pack("=11x", ))
         return buf.getvalue()
     fixed_size = 128
     @classmethod
